# Licensed under a 3-clause BSD style license - see LICENSE.rst
"""Gammapy command line interface (scripts)."""
from .spectrum_pipe import *
